#
# wls_install::cluster_node
#
# @summary Type setting up machine as a cluster node.
# Here is an example on how to use it:
# 
# ``` puppet
# }
# ```
#
# @param [String[1]] machine_name
#    Name of the weblogic machine to use.
#
# @param [String[1]] listenaddress
#    The address to use for listening.
#    Mat be a physical IP address or a DNS name.
#
# @param [Integer] ssl_listen_port
#    SSL listen port to use.
#
# @param [Integer] nodemanager_port
#    The IP port the nodemanager is listening on.
#
# @param [Array] server_arguments
#    Java argcuments to use when starting the managed server.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::cluster_node(
  String[1] $machine_name,
  String[1] $listenaddress,
  Integer   $listen_port,
  Integer   $ssl_listen_port,
  Integer   $nodemanager_port,
  String[1] $domain_name,
  Array     $server_arguments,
)
{
  easy_type::debug_evaluation() # Show local variable on extended debug

  wls_machine { "${domain_name}/${machine_name}":
    ensure        => 'present',
    listenaddress => $listenaddress,
    listenport    => $nodemanager_port,
    machinetype   => 'UnixMachine',
    nmtype        => 'SSL',
  }

  wls_install::managed_server{ $title:
    domain           => $domain_name,
    machine          => $machine_name,
    listenaddress    => $listenaddress,
    server_arguments => $server_arguments,
    listenport       => $listen_port,
    ssllistenport    => $ssl_listen_port,
  }
}
