#
# wls_install::increased_memory_bsu
#
# @summary 
# Patches the BSU utility to increase the amount of memory available for patches.
#
# @param [Stdlib::Absolutepath] middleware_home_dir
#    Middleware home directory.
#
# @param [Stdlib::Absolutepath] jdk_home_dir
#    The homdirectory for the Java evelopment Kit.
#
# @param [String[1]] os_user
#    The os user used to install and run WebLogic.
#
# @param [Srting[1]] os_group
#    The os group used to install and run WebLogic.
#
# @param [Stdlib::Absolutepath] download_dir
#    The directory where the Puppet software puts all downloaded files.
#    Before Puppet can actually use remote files, they must be downloaded first. Puppet uses this directory to put all files in.
#    The default value is: `/install`
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::increased_memory_bsu (
  Stdlib::Absolutepath $middleware_home_dir = lookup({name => 'wls_middleware_home_dir'}),
  Stdlib::Absolutepath $jdk_home_dir        = lookup({name => 'wls_jdk_home_dir'}),
  String[1]            $os_user             = lookup({name => 'wls_os_user'}),
  Srting[1]            $os_group            = lookup({name => 'wls_os_group'}),
  Stdlib::Absolutepath $download_dir        = lookup({name => 'wls_download_dir'}),
  Variant[
    Boolean,
    Enum[
      'on_failure'
    ]
  ]                    $logoutput           = lookup({name => 'logoutput', default_value => 'on_failure'}),
)
{
  $exec_path = "/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:${jdk_home_dir}/bin"

  easy_type::debug_evaluation() # Show local variable on extended debug

  exec { "change memory params for ${name}":
    command   => "sed -e's/MEM_ARGS=\"-Xms256m -Xmx512m\"/MEM_ARGS=\"-Xms256m -Xmx1024m -XX:-UseGCOverheadLimit\"/g' ${middleware_home_dir}/utils/bsu/bsu.sh > ${download_dir}/bsu.sh && mv ${download_dir}/bsu.sh ${middleware_home_dir}/utils/bsu/bsu.sh;chmod +x ${middleware_home_dir}/utils/bsu/bsu.sh",
    unless    => "grep 'MEM_ARGS=\"-Xms256m -Xmx1024m -XX:-UseGCOverheadLimit\"' ${middleware_home_dir}/utils/bsu/bsu.sh",
    path      => $exec_path,
    user      => $os_user,
    group     => $os_group,
    cwd       => $download_dir,
    logoutput => $logoutput,
  }
}
