#
# wls_install::managed_server
#
# @summary Type defined for setting up managed server.
#
#
# @param [String[1]] domain
#    Domain name.
#
# @param [String[1]] machine
#    Name of the weblogic machine to use.
#
# @param [String[1]] listenaddress
#    The address to use for listening.
#    Mat be a physical IP address or a DNS name.
#
# @param [Integer] listenport
#    IP port to listen on.
#
# @param [Integer] ssllistenport
#    SSL listen port to use.
#
# @param [Array] server_arguments
#    Java arguments to use when runing the managed server.
#
# @param [Optional[Stdlib::Absolutepath]] wls_log_dir
#    The directory where all log files are places.
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::managed_server(
  String[1]                      $domain,
  String[1]                      $machine,
  String[1]                      $listenaddress,
  Integer                        $listenport,
  Integer                        $ssllistenport,
  Array                          $server_arguments,
  Optional[Stdlib::Absolutepath] $wls_log_dir = lookup({name => 'wls_log_dir', default_value => undef}),
)
{

  easy_type::debug_evaluation() # Show local variable on extended debug

  wls_server{"${domain}/${title}":
    ensure                         => present,
    listenaddress                  => $listenaddress,
    listenport                     => $listenport,
    arguments                      => $server_arguments,
    logfilename                    => "${wls_log_dir}/${title}.log",
    log_file_min_size              => 5000,
    log_filecount                  => 10,
    log_number_of_files_limited    => 1,
    log_rotate_logon_startup       => 1,
    log_rotationtype               => bySize,
    machine                        => $machine,
    sslenabled                     => 0,
    ssllistenport                  => $ssllistenport,
    sslhostnameverificationignored => 1,
    jsseenabled                    => 1,
    tunnelingenabled               => 1,
  }
}
