#
# wls_install::ords::software
#
# @summary This defined type allows you to install ords software.
#
#
# @param [String[1]] file
#    The name of the ords install file.
#
# @param [Stdlib::Absolutepath] ords_home
#    The ords home path.
#
# @param [String[1]] source
#    Source for the operation.
#
# @param [String[1]] version
#    The version that is installed in the used Oracle home.
#    Puppet uses this value to decide on version specific actions.
#
# @param [Variant[Enum['on_failure'], Boolean]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
class wls_install::ords::software(
  String[1]                            $version,
  String[1]                            $source,
  String[1]                            $file,
  Stdlib::Absolutepath                 $ords_home,
  Variant[Enum['on_failure'], Boolean] $logoutput       = 'on_failure',    # Output of the execs
){
  easy_type::debug_evaluation() # Show local variable on extended debug

  wls_install::ords::software_version { $version:
    source    => $source,
    file      => $file,
    ords_home => $ords_home,
    logoutput => $logoutput,
  }
}
