#
# wls_install::support::params
#
# @summary Support class ensuring neccecary params.
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class wls_install::support::params
{

  $os_oracle_home = $::hostname ? {
    wls12    => '/oracle/product',
    soabeta2 => '/opt/oracle/wls',
    oimapp   => '/opt/oracle',
    default  => '/opt/wls',
  }

  $ora_inventory = $::hostname ? {
    soabeta2 => '/home/oracle/soabetainv',
    wls12    => '/oracle/oraInventory',
    oimapp   => '/opt/oracle/oraInventory',
    default  => '/opt/wls/oraInventory',
  }

  $os_domain_type = $::hostname ? {
    devagent31 => 'soa',
    wls12      => 'admin',
    oimapp     => 'oim',
    default    => 'web',
  }

  $os_log_folder = $::hostname ? {
    default => '/data/logs',
  }


  $os_download_folder = $::hostname ? {
    default => '/data/install',
  }

  $shell = $::operatingsystem ? {
    'Solaris' => '/usr/bin/ksh',
    default   => '/bin/sh',
  }

  $os_mdw_home = $::hostname ?  {
    wls12   => "${os_oracle_home}/Middleware12c",
    default => "${os_oracle_home}/Middleware11gR1",
  }

  $os_wl_home = $::hostname ?  {
    wls12   => "${os_oracle_home}/Middleware12c/wlserver",
    default => "${os_oracle_home}/Middleware11gR1/wlserver_10.3",
  }

  $ora_user = $::hostname ? {
    default => 'oracle',
  }

  $ora_group = $::hostname ? {
    default => 'dba',
  }

  $user_home = $::operatingsystem ? {
    'Solaris' => '/export/home',
    default   => '/home',
  }

  $ora_inst_home = $::operatingsystem ? {
    'Solaris' => '/var/opt',
    default   => '/etc',
  }

  $os_domain = $::hostname ? {
    wls12   => 'Wls12c',
    oimapp  => 'oimDomain',
    default => 'osbSoaDomain',
  }

  $os_domain_path = $::hostname ? {
    default => "${os_mdw_home}/user_projects/domains/${os_domain}",
  }

  $node_mgr_path = $::hostname ?  {
    wls12   => "${os_mdw_home}/user_projects/domains/${os_domain}/bin",
    default => "${os_wl_home}/server/bin",
  }

  $node_mgr_port = $::hostname ?  {
    default => 5556,
  }

  $node_mgr_address = $::hostname ?  {
    default => 'localhost',
  }

  $wls_user = $::hostname ?  {
    default => 'weblogic',
  }

  $wls_password = $::hostname ?  {
    default => 'weblogic1',
  }

  $wls_adminserver = $::hostname ?  {
    default => 'AdminServer',
  }

  $jsse_enabled = $::hostname ?  {
    default => false,
  }

  easy_type::debug_evaluation() # Show local variable on extended debug
}
